@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 use utf8; # filenames can be in utf8
 
@@ -217,13 +217,13 @@ sub	input_file_with_images {
 	} close $fh;
 	return 1
 }
-
+sub	clear_input_images { $#{ $_[0]->{'input-images'} } = -1 }
 # Add using a single pattern/searchdir
 # add image files via a pattern and an input dir, e.g. '*.png', '/x/y/z/'
 # make sure that the order you expect is what you get during the pattern materialisation
 # the search dir is optional, default is Cwd::cwd
 sub	input_pattern {
-	my ($self, $apattern, $indir) = @_;
+	my ($self, $_pattern, $indir) = @_;
 	my $parent = ( caller(1) )[3] || "N/A";
 	my $whoami = ( caller(0) )[3];
 	my $verbos = $self->verbosity();
@@ -231,10 +231,17 @@ sub	input_pattern {
 		$indir = Cwd::cwd;
 		if( $verbos > 0 ){ print STDERR "${whoami} (via $parent), line ".__LINE__." : warning, no search dir was specified and using current dir '$indir'.\n" }
 	}
+	my $pattern;
+	if( $_pattern =~ m!^regex\(/(.*?)/(.*?)\)$! ){
+		# see https://www.perlmonks.org/?node_id=1210675
+		my $pa = $1; my $mo = $2;
+		if( $mo!~/^[msixpodualn]+$/ ){ print STDERR "${whoami} (via $parent), line ".__LINE__." : error, illegal modifiers ($mo) to the specified regex detected.\n"; return 0 }
+		$pattern = qr/(?${mo})${pa}/;
+	} else { $pattern = $_pattern }
 	if( ! defined $self->input_images([
 		File::Find::Rule
 			->file()
-			->name($apattern)
+			->name($pattern)
 			->in($indir)
 	]) ){ print STDERR "${whoami} (via $parent), line ".__LINE__." : error, call to input_images() has failed.\n"; return 0 }
 	return 1 # success
@@ -296,13 +303,13 @@ Automate::Animate::FFmpeg - Create animation from a sequence of images using ffm
 
 =head1 VERSION
 
-Version 0.01
+Version 0.02
 
 
 =head1 SYNOPSIS
 
 This module creates an animation from a sequence of input
-images using L<https://ffmpeg.org/|FFmpeg>.
+images using L<FFmpeg|https://ffmpeg.org>.
 An excellent, open source program.
 
     use Automate::Animate::FFmpeg;
@@ -356,8 +363,15 @@ All arguments are supplied via a hashref with the following keys:
 which complies to what L<File::Find::Rule> understands (See [https://metacpan.org/pod/File::Find::Rule#Matching-Rules]).
 For example C<*.png>, regular expressions can be passed by enclosing them in C<regex(/.../modifiers)>
 and should include the C<//>. Modifiers can be after the last C</>. For example C<regex(/\.(mp3|ogg)$/i)>.
+
 The optional second parameter is the search path. If not specified, the current working dir will be used.
 
+Note that there is no implicit or explicit C<eval()> in compiling the user-specified
+regex (i.e. when pattern is in the form C<regex(/.../modifiers)>).
+Additionally there is a check in place for the user-specified modifiers to the regex:
+C<die "never trust user input" unless $modifiers=~/^[msixpodualn]+$/;>.
+Thank you L<Discipulus|https://www.perlmonks.org/?node_id=174111>.
+
 =item * C<input-patterns> : same as above but it expects an array of C<input-pattern>.
 
 =item * C<input-images-from-file> : specify the file which contains pathnames to image files, each on its own line.
@@ -405,7 +419,8 @@ with all the input images specified via one or more calls to any of:
 =back
 
 On success, the resultant animation will be
-written to the output file (specified using L<output_filename($m) before the call>
+written to the output file
+(specified using L<output_filename($m)> before the call.
 
 It returns 0 on failure, 1 on success.
 
@@ -424,8 +439,11 @@ the animation.
 
 Initiates a search via L<File::Find::Rule> for the
 input image files to make up the animation using
-the pattern C<$m->[0]> with starting search dir being C<$m->[1]>,
+the pattern C<$m-E<gt>[0]> with starting search dir being C<$m-E<gt>[1]>,
 which is optional -- default being C<Cwd::cwd> (current working dir).
+So, C<$m> is an array ref of one or two items. The first is the search
+pattern and the optional second is the search path, defaulting to the current
+working dir.
 
 The pattern (C<$m->[0]>) can be a shell wildcard, e.g. C<*.png>,
 or a regex specified as C<regex(/REGEX-HERE/modifiers)>, for example
@@ -482,6 +500,13 @@ It returns 0 on failure, 1 on success.
 It returns the number of input images currently
 in the list to make up the animation.
 
+=head2 C<clear_input_images()>
+
+  $aaFF->clear_input_images();
+
+It clears the list of input images to make up an animation.
+Zero, null, it's over for Bojo.
+
 =head2 C<ffmpeg_executable()>
 
   my $ret = $aaFF->ffmpeg_executable();
@@ -505,6 +530,13 @@ It sets or gets the frame duration in (fractional) seconds.
 Frame duration is the time that each frame(=image) appears
 in the produced animation.
 
+
+=head1 SCRIPTS 
+
+A script for making animations from input images using C<ffmpeg>
+is provided: C<automate-animate-ffmpeg.pl>.
+
+
 =head1 AUTHOR
 
 Andreas Hadjiprocopis, C<< <bliako at cpan.org> >>
@@ -550,6 +582,23 @@ L<https://metacpan.org/release/Automate-Animate>
 
 =head1 ACKNOWLEDGEMENTS
 
+=over 2
+
+=item * A big thank you to L<FFmpeg|https://ffmpeg.org>, an
+excellent, open source software for all things moving.
+
+=item * A big thank you to L<PerlMonks|https://perlmonks.org>
+for the useful L<discussion|https://perlmonks.org/?node_id=11156484>
+on parsing command line arguments as a string. And an even bigger
+thank you to L<PerlMonks|https://perlmonks.org> for just being there.
+
+=item * On compiling a regex when pattern and modifiers are in
+variables, L<discussion|https://www.perlmonks.org/?node_id=1210675>
+at L<PerlMonks|https://perlmonks.org>.
+
+=item * A big thank you to Ace, the big dog. Bravo Ace!
+
+=back
 
 =head1 LICENSE AND COPYRIGHT
 
